# --------------------------------------------------------------------------
#    "makeGnu.make" - build KUCRS executables with GNU compiler
#                     on Linux/UNIX/BSD
#       This is a part of KUCRS:
#          Knowledge-basing Utilities for Complex Reaction Systems
#                       (c) 2002-2016 by A. Miyoshi, University of Tokyo
#                                  last edited: Mar. 23, 2016
# --------------------------------------------------------------------------

# ----- Operating-System dependent commands and file extensions --------

# --- Linux/UNIX/BSD
RM = rm -f
MV = mv
AR = ar cr 
XO = o
XA = a
MVEXEC = find . -type f -perm /+x -exec mv -f {} ../bin \;
# for msys/cygwin
#MVEXEC = mv -f *.exe ../bin

# --- Windows
#RM = del
#MV = move
#AR = lib /OUT:
#XO = obj
#XA = lib
#MVEXEC = move /y *.exe ../bin

# ----- names of C++ and Fortran compilers and options -----------------
# ----- suggested names of C++ and Fortran compilers
#  GNU compiler (version 4)         .. g++, gcc, gfortran
#               (version 3)         .. g++, gcc, g77
#  Intel compilers for Linux/MacOS  .. icc, icc, ifort
#                  for Windows      .. icl, icl, ifort
# ----- suggested optimization flags
#  Intel compilers for Windows      .. -O2
#  Others                           .. -O
# ----------------------------------------------------------------------

CPCMP = g++
#CPCMP = icc
#CPCMP = icl

CCMP = gcc -lm
#CCMP = icc
#CCMP = icl

F7CMP = gfortran
#F7CMP = g77
#F7CMP = ifort

#CFLG = -O2
CFLG = -O

# ===== no need to edit below in usual circumstances =======================

OBJMLB = libfunc.$(XO) element.$(XO) molecule.$(XO)
OBJCMB = moleclst.$(XO) reaction.$(XO)
OBJCGN = libfunc.$(XO) element.$(XO) rxnmacro.$(XO)
OBJTGN = libfunc.$(XO) joback.$(XO)
MINPLB = minpack.$(XA)

all: mollib combust chemgen trangen thermgen remNrot smiles2mol mol2smiles thermpac pac99m c97to7m

mollib : mollib.$(XO) $(OBJMLB)
	$(CPCMP) $(CFLG) mollib.$(XO) $(OBJMLB) -o mollib

smiles2mol : smiles2mol.$(XO) $(OBJMLB)
	$(CPCMP) $(CFLG) smiles2mol.$(XO) $(OBJMLB) -o smiles2mol

mol2smiles : mol2smiles.$(XO) $(OBJMLB)
	$(CPCMP) $(CFLG) mol2smiles.$(XO) $(OBJMLB) -o mol2smiles

combust : combust.$(XO) $(OBJMLB) $(OBJCMB)
	$(CPCMP) $(CFLG) combust.$(XO) $(OBJMLB) $(OBJCMB) -o combust

chemgen : chemgen.$(XO) $(OBJCGN)
	$(CPCMP) $(CFLG) chemgen.$(XO) $(OBJCGN) -o chemgen

trangen : trangen.$(XO) $(OBJTGN)
	$(CPCMP) $(CFLG) trangen.$(XO) $(OBJTGN) -o trangen

thermgen : thermgen.c
	$(CCMP) $(CFLG) thermgen.c -o thermgen

remNrot : remNrot.c
	$(CCMP) $(CFLG) remNrot.c -o remNrot

libfunc.$(XO) : libfunc.cc libfunc.h
	$(CPCMP) $(CFLG) -c libfunc.cc

element.$(XO) : element.cc element.h libfunc.h
	$(CPCMP) $(CFLG) -c element.cc

molecule.$(XO) : molecule.cc molecule.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c molecule.cc

moleclst.$(XO) : moleclst.cc moleclst.h molecule.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c moleclst.cc

reaction.$(XO) : reaction.cc reaction.h moleclst.h molecule.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c reaction.cc

rxnmacro.$(XO) : rxnmacro.cc rxnmacro.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c rxnmacro.cc

joback.$(XO) : joback.cc joback.h libfunc.h
	$(CPCMP) $(CFLG) -c joback.cc

mollib.$(XO) : mollib.cc molecule.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c mollib.cc

smiles2mol.$(XO) : smiles2mol.cc molecule.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c smiles2mol.cc

mol2smiles.$(XO) : mol2smiles.cc molecule.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c mol2smiles.cc

combust.$(XO) : combust.cc reaction.h moleclst.h molecule.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c combust.cc

chemgen.$(XO) : chemgen.cc rxnmacro.h element.h libfunc.h
	$(CPCMP) $(CFLG) -c chemgen.cc

trangen.$(XO) : trangen.cc joback.h libfunc.h
	$(CPCMP) $(CFLG) -c trangen.cc

thermpac : thermpac.f minpack.$(XA)
	$(F7CMP) $(CFLG) thermpac.f minpack.$(XA) -o thermpac

minpack.$(XA) : minpack/*.f
	cd minpack && \
	$(F7CMP) $(CFLG) -c *.f && \
	$(AR)../$(MINPLB) *.$(XO) && \
	$(RM) *.$(XO) && \
	cd ..

pac99m : pac99m.f
	$(F7CMP) $(CFLG) pac99m.f -o pac99m

c97to7m : c97to7m.f
	$(F7CMP) $(CFLG) c97to7m.f -o c97to7m

clean:
	$(RM) *.$(XO) *.$(XA)

install:
	$(MVEXEC)

