/*--------------------------------------------------------------------------
     "remNrot.c" - post processor for NASA thermodata generated by thermfit
        This is a part of KUCRS:
           Knowledge-basing Utilities for Complex Reaction Systems
                        (c) 2002-2010 by A. Miyoshi, University of Tokyo
                                       created: Oct.   3, 2001
                                        edited: Jan.  21, 2002
                                   last edited: June  16, 2011
----------------------------------------------------------------------------
 usage: remNrot infile outfile
--------------------------------------------------------------------------*/

#ifndef _CRT_SECURE_NO_WARNINGS
#define _CRT_SECURE_NO_WARNINGS
#endif

#include <stdio.h>
#include <string.h>

#define MXLenFN 256             /* maximum length of file names */
#define MXLen1L 512             /* maximum length of one line */
#define NORM    0               /* normal end */
#define ERRE    (-1)            /* error end */

int getALine(FILE *inf);
char buf[MXLen1L];

/*===== main =========================================================*/
int main(int argc, char *argv[]) {
char inFile[MXLenFN], outFile[MXLenFN];
int lenbuf, i;
FILE *inf, *outf;
  if (argc != 3)
    { printf(" usage: remNrot infile outfile\n"); return 0; }
  strcpy(inFile, argv[1]); strcpy(outFile, argv[2]);
  if ((inf = fopen(inFile, "rt")) == NULL)
    { printf(" Failed to open %s!\n", inFile); return 0; }
  if ((outf = fopen(outFile, "wt")) == NULL) {
    printf(" Failed to open %s!\n", outFile);
    fclose(inf); return 0;
  }
  while (getALine(inf) == NORM) {
    lenbuf = strlen(buf);
    if ((lenbuf == 80) && (buf[79] == '1'))
      { for (i = 73; i < 79; ++i) buf[i] = ' '; }
    fprintf(outf, "%s\n", buf);
  }
  fclose(outf);
  fclose(inf);
  return 0;
}

/*----- get a line ---------------------------------------------------*/
int getALine(FILE *inf) {
size_t lens;
  if (fgets(buf, MXLen1L, inf) == NULL) return ERRE;
  lens = strlen(buf);
  if (lens > 0) {
    if (buf[lens - 1] == '\n') buf[lens - 1] = '\0';
  }
  return NORM;
}

