/* -------------------------------------------------------------------------
     "smiles2mol.cc" - convert SMILES to KUCRS-mol format
        This is a part of KUCRS:
           Knowledge-basing Utilities for Complex Reaction Systems
                        (c) 2002-2015 by A. Miyoshi, University of Tokyo
                                       created: Mar.  10, 2010
                                   last edited: Dec.   4, 2015
 --------------------------------------------------------------------------
 usage: smiles2mol SMILESinput MOLoutput [-s|r|t]
------------------------------------------------------------------------- */

#include "molecule.h"
using namespace std;

/*===== main routien =====================================================*/

int main(int argc, char *argv[]) {
  long mtyp;
  int setRxnDone = false, resetRxnDone = false, outThgInp = false;
  string cdate, nam, ssmls, chemForm, typ, clopt = "";
  string strthg, fnInp, fnBas, fnThg;
  vector<string> vsin, vs;
  ofstream ots;
  molecule spc;
  groupLib grp;
  typeMolec tym;

  if ((argc < 3) || (argc > 4))
    { cout << "usage: smiles2mol SMILESinput MOLoutput [-s|r|t]\n"; return 1; }
  if (argc == 4) {
    clopt = argv[3];
    if (clopt == "-s") { setRxnDone = true; }
    else if (clopt == "-r") { resetRxnDone = true; }
    else if (clopt == "-t") { outThgInp = true; }
    else
     { cout << "usage: smiles2mol SMILESinput MOLoutput [-s|r|t]\n"; return 1; }
  }
  fnInp = argv[1]; fnBas = getBaseName(fnInp); fnThg = fnBas + "_thg.inp";
  cdate = "(" + strCurDate() + ")";
  cout << "--- Program smiles2mol " << cdate << " ---\n";
  ifstream ifs(argv[1]);
  if (!ifs) { cout << "failed to open [" << argv[1] << "].\n"; return 1; }
  ofstream ofs(argv[2]);
  if (!ofs) { cout << "failed to open [" << argv[2] << "].\n"; return 1; }
  if (outThgInp) {
    ots.open(fnThg.c_str());
    if (!ots) { cout << "failed to open [" << fnThg << "].\n"; return 1; }
    ots << "Thermodata generated by smiles2mol " << cdate << endl;
  }
  while (getTokensFrom(ifs, 2, vsin) == NORM) {
    nam = vsin[0]; ssmls = vsin[1];
    if (spc.setFromSMILES(ssmls, nam) == ERRE)
      { cout << "invalid input: " << nam << " " << ssmls << endl; return 1; }
    spc.beUnique();
    if (setRxnDone) { spc.isRxnDone = true; }
    else if (resetRxnDone) { spc.isRxnDone = false; }
    spc.getUniqueView(vs);
    spc.storeTo(ofs);
    chemForm = spc.molec.getChemFormula();
    mtyp = spc.getType(grp); typ = tym.typNameExt(mtyp);
    cout << "-----------------------------------------------------------\n";
    cout << " name:    " << spc.molName << endl;
    cout << " formula: " << chemForm << endl;
    cout << " SMILES:  " << spc.getSMILES() << endl;
    cout << " struct:\n" << vs;
    strthg = spc.getThermInput(grp);
    cout << " groups: " << strthg << endl;
    cout << " code:    " << hex << mtyp << dec;
    if (typ != "") { cout << " (" << typ << ")"; }
    cout << endl;
    if (outThgInp) { ots << strthg << endl; }
  }
  if (outThgInp) { ots.close(); }
  ofs.close();
  ifs.close();
  return 0;
}

